@@ -1,5 +1,6 @@
 import os
 import json
+import sys
 
 from .utils import Utils, DockerError, S3Error
 from threading import Timer
@@ -131,7 +132,10 @@ class ScanRunner(object):
             container = client.containers.run(docker_image, command_line, volumes=volumes, detach=True, tty=False, stdout=True, stderr=True)
             container.wait()
         except Exception as de:
-            raise DockerError('Failed to run docker image: ' + str(de)) from de
+            if sys.version_info < (3, 0):
+                raise DockerError('Failed to run docker image: ' + str(de))
+            else:
+                raise DockerError('Failed to run docker image: ' + str(de)) from de
 
         # write stdout and stderr output
         try:
