@@ -92,7 +92,7 @@ class Utils(object):
 		if stdout is not None and stdout.decode('utf-8').find('Login Succeeded') >= 0:
 			print('Login to docker succeeded.')
 		else:
-			raise DockerError('Login to docker failed: ' + stdout.decode('utf-8')) from None
+			raise DockerError('Login to docker failed: ' + stdout.decode('utf-8'))
 
 		client = docker.from_env()
 		cls.last_time_docker_login = cls.get_timestamp()
@@ -128,7 +128,10 @@ class Utils(object):
 			try:
 				docker_client.images.get(image)
 			except Exception as de:
-				raise DockerError('Failed to pull image: ' + str(e)) from e
+				if sys.version_info < (3, 0):
+					raise DockerError('Failed to pull image: ' + str(e))
+				else:
+					raise DockerError('Failed to pull image: ' + str(e)) from e
 
 		
 	@classmethod
@@ -392,6 +395,6 @@ class Utils(object):
 			
 			print('Output file uploaded')
 		except Exception as e:
-			raise S3Error('Failed to upload output file: ' + str(e)) from None
+			raise S3Error('Failed to upload output file: ' + str(e))
 
 		return timestamp
